pub async fn upload_file_to_server(
local_file_path: String,
user_id: String,
) -> Result<(), Box<dyn Error>>Expand description
Upload a local file to the server for syncing
This allows users to upload their files to the server so they can be accessed from other clients and their reading progress can be tracked online.
Arguments
local_file_path- Path to the local file to uploaduser_id- User identifier
Returns
Result<(), Box<dyn std::error::Error>>- Result indicating success or error